@@ -27,6 +27,17 @@ import opsramp.msp
 CATEGORY_NAME = 'Testing 123'
 
 
+def sanitize_response(resp):
+    config = resp.get('inboundConfig', {})
+    auth = config.get('authentication', {})
+    if 'token' in auth:
+        auth['token'] = 'REDACTED'
+    for creds in auth.get('apiKeyPairs', {}):
+        for i in creds.keys():
+            creds[i] = 'REDACTED'
+    return resp
+
+
 def main():
     OPSRAMP_URL = os.environ.get('OPSRAMP_URL')
     TENANT_ID = os.environ.get('OPSRAMP_TENANT_ID')
@@ -55,6 +66,19 @@ def main():
     print(found['totalResults'], 'integration types')
     for i in found['results']:
         print(i)
+
+    print('Define new custom integrations on', TENANT_ID)
+    for atype in ('OAUTH2', 'BASIC'):
+        newcint = ints.mkCustom(
+            display_name='Example %s integration' % atype,
+            inbound_auth_type=atype
+        )
+        print(newcint)
+        # uncomment the following lines to actually create the integration.
+        # resp = ints.create_instance('CUSTOM', newcint)
+        # sanitize_response(resp)
+        # print(resp)
+
     group = ints.instances()
     found = group.search()
     print(found['totalResults'], 'integration instances')
@@ -63,7 +87,7 @@ def main():
     for i in found['results']:
         print('...', i['id'], i['integration']['id'],
               '"' + i.get('displayName', '<no name>') + '"')
-        ithis = group.instance(i['id'])
+        ithis = ints.instance(i['id'])
         direct = ithis.get()
         assert direct == i
 
