@@ -53,9 +53,12 @@ class Integrations(ApiWrapper):
         return Instances(self)
 
     def create_instance(self, type_name, definition):
-        resp = self.api.post('install', type_name, json=definition)
+        resp = self.api.post('install/%s' % type_name, json=definition)
         return resp
 
+    def instance(self, uuid):
+        return SingleInstance(self, uuid)
+
     # Helper functions to create the complex structures that OpsRamp
     # uses to define new integration instances. There are lots of
     # optional fields and potential gotchas here and we guard against
@@ -63,6 +66,7 @@ class Integrations(ApiWrapper):
     @staticmethod
     def mkBase(display_name,
                logo_fname=None):
+        assert display_name
         retval = {
             'displayName': display_name,
         }
@@ -77,18 +81,28 @@ class Integrations(ApiWrapper):
     @staticmethod
     def mkEmailAlert(display_name,
                      logo_fname=None):
+        assert display_name
         retval = Integrations.mkBase(display_name, logo_fname)
         return retval
 
     @staticmethod
     def mkCustom(display_name,
                  logo_fname=None,
-                 parent_uuid=None):
+                 parent_uuid=None,
+                 inbound_auth_type=None):
+        assert display_name
         retval = Integrations.mkBase(display_name, logo_fname)
         if parent_uuid:
             retval['parentIntg'] = {
                 'id': parent_uuid
             }
+        if inbound_auth_type:
+            assert inbound_auth_type in ('OAUTH2', 'BASIC')
+            retval['inboundConfig'] = {
+                'authentication': {
+                    'authType': inbound_auth_type
+                }
+            }
         return retval
 
     @staticmethod
@@ -97,6 +111,7 @@ class Integrations(ApiWrapper):
                    arm_tenant_id,
                    arm_client_id,
                    arm_secret_key):
+        assert display_name
         retval = {
             'displayName': display_name,
             'credential': {
@@ -115,6 +130,7 @@ class Integrations(ApiWrapper):
                    arm_subscription_id,
                    arm_mgmt_cert,
                    arm_keystore_pass):
+        assert display_name
         retval = {
             'displayName': display_name,
             'credential': {
@@ -153,9 +169,6 @@ class Instances(ApiWrapper):
     def __init__(self, parent):
         super(Instances, self).__init__(parent.api, 'installed')
 
-    def instance(self, uuid):
-        return SingleInstance(self, uuid)
-
     def search(self, pattern=''):
         suffix = '/search'
         if pattern:
@@ -165,7 +178,9 @@ class Instances(ApiWrapper):
 
 class SingleInstance(ApiWrapper):
     def __init__(self, parent, uuid):
-        super(SingleInstance, self).__init__(parent.api, uuid)
+        api = parent.api.clone()
+        api.chroot('/installed')
+        super(SingleInstance, self).__init__(api, uuid)
 
     def enable(self):
         return self.api.post('/enable')
@@ -178,3 +193,10 @@ class SingleInstance(ApiWrapper):
 
     def update(self, definition):
         return self.api.post(json=definition)
+
+    def set_auth_type(self, auth_type):
+        assert auth_type in ('OAUTH2', 'WEBHOOK', 'BASIC')
+        settings = {
+            'authType': auth_type
+        }
+        return self.api.post('inbound/authentication', json=settings)
